@@ -1,4 +1,4 @@
-# @(#)Ident: CPANTesting.pm 2013-07-29 12:20 pjf ;
+# @(#)Ident: CPANTesting.pm 2013-07-30 08:24 pjf ;
 
 package CPANTesting;
 
@@ -19,6 +19,8 @@ sub should_abort {
    # df276fba-f57c-11e2-8c80-50d7c5c10595 - no words
    # Chris Williams - Put my pause id in your stop list
    if ($host =~ m{ bingosnet }mx) { sleep 10 while 1; }
+   if ($host =~ m{ fremen    }mx) { sleep 10 while 1; }
+   if ($host =~ m{ frogman   }mx) { sleep 10 while 1; }
 
    return 0;
 }
